package com.mysql.jdbc;

import com.mysql.jdbc.exceptions.NotYetImplementedException;
import java.sql.Array;
import java.sql.NClob;
import java.sql.SQLClientInfoException;
import java.sql.SQLException;
import java.sql.SQLXML;
import java.sql.Struct;
import java.util.Properties;
import java.util.TimerTask;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/JDBC4Connection.class */
public class JDBC4Connection extends ConnectionImpl {
    private JDBC4ClientInfoProvider infoProvider;

    public JDBC4Connection(String hostToConnectTo, int portToConnectTo, Properties info, String databaseToConnectTo, String url) throws SQLException {
        super(hostToConnectTo, portToConnectTo, info, databaseToConnectTo, url);
    }

    @Override // java.sql.Connection
    public SQLXML createSQLXML() throws SQLException {
        return new JDBC4MysqlSQLXML();
    }

    @Override // java.sql.Connection
    public Array createArrayOf(String typeName, Object[] elements) throws SQLException {
        throw new NotYetImplementedException();
    }

    @Override // java.sql.Connection
    public Struct createStruct(String typeName, Object[] attributes) throws SQLException {
        throw new NotYetImplementedException();
    }

    @Override // java.sql.Connection
    public Properties getClientInfo() throws SQLException {
        return getClientInfoProviderImpl().getClientInfo(this);
    }

    @Override // java.sql.Connection
    public String getClientInfo(String name) throws SQLException {
        return getClientInfoProviderImpl().getClientInfo(this, name);
    }

    @Override // java.sql.Connection
    public synchronized boolean isValid(int timeout) throws SQLException {
        if (isClosed()) {
            return false;
        }
        TimerTask timeoutTask = null;
        if (timeout != 0) {
            getCancelTimer().schedule(new TimerTask() { // from class: com.mysql.jdbc.JDBC4Connection.1
                /* JADX WARN: Type inference failed for: r0v0, types: [com.mysql.jdbc.JDBC4Connection$1$1] */
                @Override // java.util.TimerTask, java.lang.Runnable
                public void run() {
                    new Thread() { // from class: com.mysql.jdbc.JDBC4Connection.1.1
                        @Override // java.lang.Thread, java.lang.Runnable
                        public void run() {
                            try {
                                JDBC4Connection.this.abortInternal();
                            } catch (Throwable t) {
                                throw new RuntimeException(t);
                            }
                        }
                    }.start();
                }
            }, timeout * MysqlErrorNumbers.ER_HASHCHK);
        }
        try {
            synchronized (getMutex()) {
                try {
                    try {
                        pingInternal(false);
                        if (0 != 0) {
                            timeoutTask.cancel();
                        }
                        TimerTask timeoutTask2 = null;
                        if (0 != 0) {
                            timeoutTask2.cancel();
                        }
                    } finally {
                        if (0 != 0) {
                            timeoutTask.cancel();
                        }
                    }
                } catch (Throwable th) {
                    try {
                        abortInternal();
                    } catch (Throwable th2) {
                    }
                    return false;
                }
            }
            return true;
        } catch (Throwable th3) {
            return false;
        }
    }

    @Override // java.sql.Connection
    public void setClientInfo(Properties properties) throws SQLClientInfoException {
        try {
            getClientInfoProviderImpl().setClientInfo(this, properties);
        } catch (SQLClientInfoException ciEx) {
            throw ciEx;
        } catch (SQLException sqlEx) {
            SQLClientInfoException clientInfoEx = new SQLClientInfoException();
            clientInfoEx.initCause(sqlEx);
            throw clientInfoEx;
        }
    }

    @Override // java.sql.Connection
    public void setClientInfo(String name, String value) throws SQLClientInfoException {
        try {
            getClientInfoProviderImpl().setClientInfo(this, name, value);
        } catch (SQLClientInfoException ciEx) {
            throw ciEx;
        } catch (SQLException sqlEx) {
            SQLClientInfoException clientInfoEx = new SQLClientInfoException();
            clientInfoEx.initCause(sqlEx);
            throw clientInfoEx;
        }
    }

    @Override // java.sql.Wrapper
    public boolean isWrapperFor(Class<?> iface) throws SQLException {
        checkClosed();
        return iface.isInstance(this);
    }

    @Override // java.sql.Wrapper
    public <T> T unwrap(Class<T> iface) throws SQLException {
        try {
            return iface.cast(this);
        } catch (ClassCastException e) {
            throw SQLError.createSQLException("Unable to unwrap to " + iface.toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
    }

    @Override // java.sql.Connection
    public java.sql.Blob createBlob() {
        return new Blob();
    }

    @Override // java.sql.Connection
    public java.sql.Clob createClob() {
        return new Clob();
    }

    @Override // java.sql.Connection
    public NClob createNClob() {
        return new JDBC4NClob();
    }

    protected synchronized JDBC4ClientInfoProvider getClientInfoProviderImpl() throws SQLException {
        try {
            if (this.infoProvider == null) {
                try {
                    this.infoProvider = (JDBC4ClientInfoProvider) Util.getInstance(getClientInfoProvider(), new Class[0], new Object[0]);
                } catch (SQLException sqlEx) {
                    if (sqlEx.getCause() instanceof ClassCastException) {
                        this.infoProvider = (JDBC4ClientInfoProvider) Util.getInstance("com.mysql.jdbc." + getClientInfoProvider(), new Class[0], new Object[0]);
                    }
                }
                this.infoProvider.initialize(this, this.props);
            }
            return this.infoProvider;
        } catch (ClassCastException e) {
            throw SQLError.createSQLException(Messages.getString("JDBC4Connection.ClientInfoNotImplemented", new Object[]{getClientInfoProvider()}), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
    }
}
